@@ -9,7 +9,7 @@ apt-get install -y --force-yes --no-install-recommends \
     python3-pip
 
 pushd /setup/taskgraph
-uv export --no-dev > /setup/requirements.txt
+uv export --no-cache --no-dev > /setup/requirements.txt
 uv pip install --no-cache --system --break-system-packages -r /setup/requirements.txt
 uv pip install --no-cache --system --break-system-packages --no-deps .
 popd
@@ -18,3 +18,4 @@ apt-get clean
 apt-get autoclean
 rm -rf /var/lib/apt/lists/
 rm -rf /setup
+rm /tmp/uv-*.lock
